<!DOCTYPE html>
<html>
    <head>
        <style>
            .button {
              border: none;
              color: white;
              padding: 16px 32px;
              text-align: center;
              text-decoration: none;
              display: inline-block;
              font-size: 16px;
              margin: 4px 2px;
              transition-duration: 0.4s;
              cursor: pointer;
            }
            .button_{{state}} {
              background-color: white; 
              color: black; 
              border: 4px solid #4CAF50;
              font-weight: bold;
            }

            .button_{{state}}:hover {
              background-color: #4CAF50;
              font-weight: bold;
              color: white;
            }

            .button_{{next}} {
              background-color: white; 
              color: black; 
              border: 4px solid #008CBA;
              font-weight: bold;
            }

            .button_{{next}}:hover {
              background-color: #008CBA;
              font-weight: bold;
              color: white;
            }

            h1 {text-align: center;}
            div {text-align: center;}
        </style>
    </head>
    <body>
        <h1>{{name}}</h1>
        <div>
                <button class="button button_{{state}}">{{state}} OK</button>
            <a href="{{next}}">
                <button class="button button_{{next}}">{{next}}</button>
            </a>
        </div>
    </body>
</html>
